#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Author: Goddy <goddy@mykg.ai> 2021/9/16
# Desc:

from goddy.app import say_hi
